# A countdown to 2026 in your terminal.

<img alt="Screenshot 2025-12-28 at 21 42 21" src="https://github.com/user-attachments/assets/f9872cec-27a6-4154-b481-ee9383c8e46e" />

Install with:

```
uvx ny2026
```

Requires [UV](https://docs.astral.sh/uv/getting-started/installation/)

This project was entirely vibe coded with [Toad](https://github.com/batrachianai/toad) and [Claude Code](https://code.claude.com/docs/en/overview)

Don't ask me how it works!
